@@ -1,13 +1,11 @@
 package Pcore::API::Map::Method::Destroy;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::API::Map::Method];
 
 has '+use_fields' => ( default => 'id', init_arg => undef );
 
-no Pcore;
-
 1;
 __END__
 =pod
